# -*- coding: utf-8 -*-
"""
Django LOCAL settings for sat_website project, typically to be imported from
the main settings.py file (see http://stackoverflow.com/a/4909964).

For more information on this file, see
https://docs.djangoproject.com/en/1.7/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.7/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.7/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '{{ secret_key }}'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

TEMPLATE_DEBUG = DEBUG


# Email settings

# print email to stdout instead of actually sending it
# EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

FORM_FROM_EMAIL = 'no-reply@example.net'
FORM_TO_EMAILS = ['email@example.net']


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'markdown_deux',  # https://github.com/trentm/django-markdown-deux
    'sat_website',  # needed to load the apps in templatetags
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',  # after SessionMiddleWare AND before CommonMiddleWare
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'sat_website.urls'


# Database
# https://docs.djangoproject.com/en/1.7/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

# Internationalization
# https://docs.djangoproject.com/en/1.7/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'Europe/Paris'

USE_I18N = True

USE_L10N = True

USE_TZ = True

LOCALE_PATHS = ("locale",)


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.7/howto/static-files/

STATIC_URL = '/static/'

STATICFILES_DIRS = (
    os.path.join(BASE_DIR, 'static'),
)

# Templates

TEMPLATE_DIRS = (
    os.path.join(BASE_DIR, 'templates'),
)

# Options for SàT website (see README)

# External URL pointing the external media files
MEDIA_EXTERNAL_URL = 'ftp://ftp.goffi.org/media'

# External URL pointing the projects archives directory
PROJECTS_EXTERNAL_URL = 'ftp://ftp.goffi.org'

# Internal path to the the projects archives directory
PROJECTS_INTERNAL_PATH = '/srv/ftp'

# List of couples with the project directory name and the project name (set to None if it's the same)
PROJECTS_NAMES = [('sat', None), ('sat_media', None), ('urwid-satext', 'urwid_satext'), ('sat_pubsub', None), ('libervia', None)]

# Extension used to name the project archives
ARCHIVE_SUFFIX = '.tar.bz2'

# URL to Libervia online demo
LIBERVIA_DEMO_URL = 'https://www.libervia.org'

# Actual and target number of members
ASSO_MEMBERS_ACTUAL = 3400
ASSO_MEMBERS_TARGET = 6000

# Actual and target amount to finance the association (in euros)
ASSO_FINANCE_ACTUAL = 40000
ASSO_FINANCE_TARGET = 60000

# Subscription amounts as defined in the Rules of Procedure
ASSO_SUBSCR_AMOUNTS = (0, 10, 20, 30, 50, 80, 100)

# Path the CSV file where all the subscriptions are written
ASSO_SUBSCR_CSV = "/home/souliane/sat_website_subscriptions.csv"

# Bank account information
ASSO_IBAN = u"FR76 1027 8060 4300 0207 3220 109"
ASSO_BIC = u"CMCIFR2A"

# URL to the Statutes and Rules of the association
ASSO_URL_STATUTES = 'http://repos.goffi.org/sat_docs/raw-file/tip/association/statuts.pdf'
ASSO_URL_RULES = 'http://repos.goffi.org/sat_docs/raw-file/tip/association/r%C3%A8glement%20int%C3%A9rieur.pdf'

# Import another settings file that can override these settings (for example to daily update the stats when you don't want a script to directly modify this file)
from sys import path
path.append('/home/souliane')
try:
    from sat_website_external_settings import *
except ImportError:
    pass
